import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

Page {
    id: addLocationPage
    objectName: "AddLocationPage"
    title: i18n.tr("Add city")
    visible: false
    tools: ToolbarItems{
        locked: true
        opened: true
        back: ToolbarButton {
            objectName: "BackButton"
            iconSource: Qt.resolvedUrl("../resources/images/back@18.png")
            text: i18n.tr("Back")
            onTriggered: {
                if(pageStack.depth === 3) pageStack.pop()
            }
        }
    }

    WorkerScript {
        id: searchWorker
        source: "./WeatherApi.js"
        onMessage: {
            if(!messageObject.error) {
                listView.visible = true
                messageObject.result.locations.forEach(function(loc) {
                    citiesModel.append(loc);
                    noCityError.visible = false
                });
            } else {
                console.log(messageObject.error.msg+" / "+messageObject.error.request.url)
            }
            if (!citiesModel.count) {
                noCityError.visible = true
                noCityError.text = i18n.tr("No location was found for ") + locationString.text
            }
        }
    }

    function clear() {
        locationString.text = '';
        citiesModel.clear();
        listView.visible = true;
    }

    Rectangle {
        id: searchInput
        width:parent.width
        height:units.gu(7)
        color: "transparent"
        TextField {
            id: locationString
            objectName: "SearchField"
            width: parent.width-units.gu(2)
            height:units.gu(5)
            anchors.centerIn: parent
            placeholderText: i18n.tr("Enter a city name")
            hasClearButton: true
            onAccepted: {
                citiesModel.clear();
                searchWorker.sendMessage({
                    action: "searchByName",
                    params: {name:locationString.text, units:"metric"}
                })
            }
        }
    }

    ListModel {
        id: citiesModel
    }

    Rectangle {
        id: cityList;
        anchors.top: searchInput.bottom
        width: parent.width
        height: units.gu(52)
        color: "transparent"
        Label {
            id: noCityError
            objectName: "noCityError"
            visible: false
            anchors.centerIn: parent;
            font.pixelSize: 18
        }

        ListView {
            id: listView;
            objectName: "SearchResultList"
            visible: false
            clip: true;
            anchors.fill: parent;
            model:  citiesModel;
            delegate: ListItem.Standard {
                text: i18n.tr(name)+((country) ? ', '+i18n.tr(country): '');
                progression: true;
                onClicked: {
                    var location = citiesModel.get(index)
                    locationManager.addLocation(location)
                    pageStack.pop()
                    clear()
                }
            }
            Scrollbar {
                flickableItem: listView;
                align: Qt.AlignTrailing;
            }
        }
    }

}
