/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Raúl Yeguas <neokore@gmail.com>
 *              Martin Borho <martin@borho.net>
 */
import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.Popups 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem

Component {

    ComposerSheet {
        id: sheet
        objectName: "SettingsSheet"
        title: i18n.tr("Settings")
        contentsHeight: parent.height

        container:     ListItem.ValueSelector {
            id: unitsSelector
            objectName: "UnitsSelector"
            text: i18n.tr("Temperature unit")
            values: [i18n.tr("°C"), i18n.tr("°F")]
            selectedIndex: (settings["units"] === "imperial") ? 1 : 0;
        }

        onConfirmClicked: {
            var refresh = false,
                selectedUnit = (unitsSelector.selectedIndex === 0) ? "metric" : "imperial";
            // check if temperaure scale was changed
            if(settings["units"] !== selectedUnit) {
                storage.saveSetting("units", selectedUnit);
                refresh = true;
            }
            // handling of other settings here
            // ....

            // a setting was changed, reload settings and refresh the location tabs
            if(refresh === true) {
                storage.getSettings(function(storedSettings) {
                    for(var settingName in storedSettings) {
                        settings[settingName] = storedSettings[settingName];
                    }
                    refreshData(true);
                });
            }
            PopupUtils.close(sheet)
        }
    }
}
