import QtQuick 2.0
import QtGraphicalEffects 1.0
import Ubuntu.Components 0.1

Rectangle {
    id: weatherCondition
    color: "transparent"
    state: ""

    property string condition: ""
    property bool __sun: false
    property bool __moon: false
    property bool __fewClouds: true
    property bool __scattered: false
    property bool __broken: false
    property bool __rain: false
    property bool __storm: false
    property bool __snow: false
    property bool __fog: false

    onConditionChanged: {
        // hotfix for inaccurate api data
        // see http://bugs.openweathermap.org/issues/72
        if(condition === "10") condition ="10d"
        weatherCondition.state = condition
    }

    Image {
        id: sun
        width: weatherCondition.width
        height: weatherCondition.height
        anchors.horizontalCenter: weatherCondition.horizontalCenter
        anchors.top: weatherCondition.top
        opacity: 0
        source: "../resources/images/sun.png"
        fillMode: Image.PreserveAspectFit
    }
    Image {
        id: moon
        width: weatherCondition.width
        height: weatherCondition.height
        anchors.horizontalCenter: weatherCondition.horizontalCenter
        anchors.top: weatherCondition.top
        opacity: 0
        source: "../resources/images/moon.png"
        fillMode: Image.PreserveAspectFit
    }
    Image {
        id: snowflake1
        width: weatherCondition.width/6
        height: weatherCondition.height/6
        anchors {
            left: weatherCondition.left
            leftMargin: units.gu(0)
            top: weatherCondition.top
            topMargin:weatherCondition.height/1.5
        }
        source: "../resources/images/snow.png"
        fillMode: Image.PreserveAspectFit
        opacity: 0
        //RotationAnimation { id: snowflake1_anim; running: false; targets: snowflake1; properties: "rotation"; from: 0; to: 360; duration: 30000; loops: Animation.Infinite}
    }
    Image {
        id: snowflake2
        width: weatherCondition.width/6
        height: weatherCondition.height/6
        anchors {
            left: weatherCondition.left
            leftMargin: weatherCondition.width/2.5
            top: weatherCondition.top
            topMargin:weatherCondition.height/1.5
        }
        source: "../resources/images/snow.png"
        fillMode: Image.PreserveAspectFit
        opacity: 0
        //RotationAnimation { id: snowflake2_anim; running: false; targets: snowflake2; properties: "rotation"; from: 0; to: 360; duration: 30000; loops: Animation.Infinite}
    }
    Image {
        id: snowflake3
        width: weatherCondition.width/6
        height: weatherCondition.height/6
        anchors {
            left: weatherCondition.left
            leftMargin: weatherCondition.width/1.2
            top: weatherCondition.top
            topMargin:weatherCondition.height/1.5
        }
        source: "../resources/images/snow.png"
        fillMode: Image.PreserveAspectFit
        opacity: 0
        //RotationAnimation { id: snowflake3_anim; running: false; targets: snowflake3; properties: "rotation"; from: 0; to: 360; duration: 30000; loops: Animation.Infinite}
    }
    Image {
        id: cloud1
        width: weatherCondition.width
        height: weatherCondition.height
        opacity: 0
        anchors {
            left: weatherCondition.left
            leftMargin: weatherCondition.width/3.6
            top: weatherCondition.top
            topMargin: weatherCondition.height/7.5
        }

        source: "../resources/images/cloud.png"
        fillMode: Image.PreserveAspectFit
    }
    InnerShadow {
        id: cloud1Glow
        anchors.fill: cloud1
        radius: weatherCondition.height/10
        samples: 24
        horizontalOffset: 0
        verticalOffset: weatherCondition.height/-10
        color: "#FFFFFFFF"
        source: cloud1
        opacity: 0
    }
    Image {
        id: rain1
        width: weatherCondition.width
        height: weatherCondition.height
        opacity: 0
        anchors {
            left: cloud1.left
            top: cloud1.top
            topMargin: weatherCondition.height/10
        }

        source: "../resources/images/rain.png"
        fillMode: Image.PreserveAspectFit
    }
    Image {
        id: lightning
        width: weatherCondition.width
        height: weatherCondition.height
        opacity: 0
        anchors {
            left: weatherCondition.left
            top: weatherCondition.top
            topMargin: weatherCondition.height/7.5
        }

        source: "../resources/images/lightning.png"
        fillMode: Image.PreserveAspectFit
    }
    ColorOverlay {
        id: lightningfx
        anchors.fill: lightning
        source: lightning
        color: "#FFFFFFFF"
        opacity: 0
    }
    Glow {
        id: lightningGlow
        anchors.fill: lightning
        radius: weatherCondition.width/3.6
        samples: 24
        color: "yellow"
        source: lightning
        opacity: 0
    }
    Image {
        id: cloud2
        width: weatherCondition.width/1.2
        height: weatherCondition.height/1.2
        opacity: 0
        anchors {
            left: weatherCondition.left
            leftMargin: weatherCondition.width/3.6
            top: weatherCondition.top
            topMargin: weatherCondition.height/10
        }
        source: "../resources/images/cloud_darker.png"
        fillMode: Image.PreserveAspectFit
    }
    Image {
        id: cloud_dark1
        width: weatherCondition.width/1.2
        height: weatherCondition.height/1.2
        opacity: 0
        anchors {
            left: weatherCondition.left
            leftMargin: weatherCondition.width/3.6
            top: weatherCondition.top
            topMargin: weatherCondition.height/10
        }
        source: "../resources/images/cloud_dark.png"
        fillMode: Image.PreserveAspectFit
    }
    InnerShadow {
        id: cloud_dark1Glow
        anchors.fill: cloud_dark1
        radius: weatherCondition.height/10
        samples: 24
        horizontalOffset: 0
        verticalOffset: weatherCondition.height/-10
        color: "#FFFFFFFF"
        source: cloud_dark1
        opacity: 0
    }
    Image {
        id: rain2
        width: weatherCondition.width/1.2
        height: weatherCondition.height/1.2
        opacity: 0
        anchors {
            left: weatherCondition.left
            leftMargin: weatherCondition.height/-15
            top: weatherCondition.top
            topMargin: weatherCondition.height/4.5
        }

        source: "../resources/images/rain.png"
        fillMode: Image.PreserveAspectFit
    }
    Image {
        id: fog
        width: weatherCondition.width
        height: weatherCondition.width
        anchors {
            left:weatherCondition.left
            top: weatherCondition.top
        }
        source: "../resources/images/fog.png"
        fillMode: Image.PreserveAspectFit
        opacity: 0
    }
    FastBlur {
        id: fogBlur1
        anchors.fill: fog
        source: fog
        radius: 24
        opacity: 0
    }
    Image {
        id: fog2
        width: weatherCondition.width/1.5
        height: weatherCondition.height/1.5
        anchors {
            left:weatherCondition.left
            leftMargin: weatherCondition.width/2
            top: weatherCondition.top
            topMargin: weatherCondition.height/7.5
        }
        source: "../resources/images/fog.png"
        fillMode: Image.PreserveAspectFit
        opacity: 0
    }
    FastBlur {
        id: fogBlur2
        anchors.fill: fog2
        source: fog2
        radius: 18
        opacity: 0
    }

    // CONDITION ANIMATIONS
    RotationAnimation {
        id: anim_01
        running: false
        targets: sun
        properties: "rotation"
        from: 0
        to: 10
        //loops: Animation.Infinite
        duration:1000
    }
    ParallelAnimation{
        id: anim_02
        running: false
        paused: (running && !weatherCondition.visible)
        SequentialAnimation {
            loops: Animation.Infinite
            ParallelAnimation{
                SequentialAnimation {
                    NumberAnimation { targets: cloud1; properties: "opacity"; from: 0; to: 1; duration: 1000 }
                    PauseAnimation {duration: 13000}
                    NumberAnimation { targets: cloud1; properties: "opacity"; from: 1; to: 0; duration: 1000 }
                }
                NumberAnimation {target: cloud1; property: "anchors.leftMargin"; from: weatherCondition.width/3.6; to: weatherCondition.width/-3.6; duration: 15000 }
                ScriptAction {script: cloud1.anchors.topMargin = weatherCondition.height/7.5;}
            }
            PauseAnimation {duration: 15000}
        }
        SequentialAnimation {
            loops: Animation.Infinite
            paused: (running && !weatherCondition.visible)
            PauseAnimation {duration: 17000}
            ParallelAnimation{
                SequentialAnimation {
                    NumberAnimation { targets: cloud2; properties: "opacity"; from: 0; to: 1; duration: 1000 }
                    PauseAnimation {duration: 8000}
                    NumberAnimation { targets: cloud2; properties: "opacity"; from: 1; to: 0; duration: 1000 }
                }
                NumberAnimation { target: cloud2; property: "anchors.leftMargin"; from: weatherCondition.width/3.6; to: weatherCondition.height/-7.5; duration: 10000}
                ScriptAction {script: cloud2.anchors.topMargin = weatherCondition.height/10;}
            }
        }
    }
    ParallelAnimation {
        id: anim_11
        running: false
        loops: Animation.Infinite
        paused: (running && !weatherCondition.visible)
        SequentialAnimation{
            PauseAnimation { duration: 2000 }
            NumberAnimation {targets: cloud1Glow; properties: "opacity"; from: 0; to: 1; duration: 10}
            NumberAnimation {targets: cloud1Glow; properties: "opacity"; from: 1; to: 0; duration: 1000}
        }
        SequentialAnimation{
            PauseAnimation { duration: 3000 }
            NumberAnimation {targets: cloud_dark1Glow; properties: "opacity"; from: 0; to: 1; duration: 10}
            NumberAnimation {targets: cloud_dark1Glow; properties: "opacity"; from: 1; to: 0; duration: 1000}
        }
        SequentialAnimation{
            PauseAnimation { duration: 2000 }
            ParallelAnimation{
                NumberAnimation {targets: lightning; properties: "opacity"; from: 0; to: 1; duration: 10}
                NumberAnimation {targets: lightningfx; properties: "opacity"; from: 0; to: 1; duration: 10}
                NumberAnimation {targets: lightningGlow; properties: "opacity"; from: 0; to: 1; duration: 10}
            }
            ParallelAnimation {
                NumberAnimation {targets: lightningGlow; properties: "opacity"; from: 1; to: 0; duration: 1000}
                NumberAnimation {targets: lightningfx; properties: "opacity"; from: 1; to: 0; duration: 1000}
                NumberAnimation {targets: lightning; properties: "opacity"; to: 0; duration: 2000}
            }
        }
    }
    ParallelAnimation {
        id: anim_13
        running: false
        paused: (running && !weatherCondition.visible)
        SequentialAnimation {
            //loops: Animation.Infinite

            //PauseAnimation { duration: 1000 }
            ParallelAnimation{
                NumberAnimation {target: snowflake1; properties: "anchors.topMargin"; from:weatherCondition.height/1.5; to:weatherCondition.height*0.83; duration: 2000}
                NumberAnimation {target: snowflake1; properties: "anchors.leftMargin"; from:weatherCondition.width/6; to:weatherCondition.height/15; duration: 2000}
                NumberAnimation {target: snowflake1; easing.type: Easing.InQuint; properties: "opacity"; from: 0; to: 1; duration: 2000}
            }
        }
        SequentialAnimation {
            //loops: Animation.Infinite

            PauseAnimation { duration: 1000 }
            ParallelAnimation {
                NumberAnimation {target: snowflake2; properties: "anchors.topMargin"; from:weatherCondition.height/1.5; to:weatherCondition.height*0.8; duration: 2000}
                NumberAnimation {target: snowflake2; properties: "anchors.leftMargin"; from:weatherCondition.width/2; to:weatherCondition.width/2.5; duration: 2000}
                NumberAnimation {target: snowflake2; easing.type: Easing.InQuint; properties: "opacity"; from: 0; to: 1; duration: 2000}
            }
        }
        SequentialAnimation {
            //loops: Animation.Infinite

            PauseAnimation { duration: 500 }
            ParallelAnimation {
                NumberAnimation {target: snowflake3; properties: "anchors.topMargin"; from:weatherCondition.height/1.5; to:weatherCondition.height*0.86; duration: 2000}
                NumberAnimation {target: snowflake3; properties: "anchors.leftMargin"; from:weatherCondition.width/1.2; to:weatherCondition.width/1.4; duration: 2000}
                NumberAnimation {target: snowflake3; easing.type: Easing.InQuint; properties: "opacity"; from: 0; to: 1; duration: 2000}
            }
        }
    }
    ParallelAnimation{
        id: anim_50
        running: false
        paused: (running && !weatherCondition.visible)
        SequentialAnimation {
            loops: Animation.Infinite
            ParallelAnimation{
                SequentialAnimation {
                    NumberAnimation { targets: fogBlur1; properties: "opacity"; from: 0; to: 1; duration: 1000 }
                    PauseAnimation {duration: 13000}
                    NumberAnimation { targets: fogBlur1; properties: "opacity"; from: 1; to: 0; duration: 1000 }
                }
                NumberAnimation {target: fogBlur1; property: "anchors.leftMargin"; from: weatherCondition.width/-3.6; to: weatherCondition.width/3.6; duration: 15000 }
            }
            PauseAnimation {duration: 2000}
        }
        SequentialAnimation {
            loops: Animation.Infinite
            PauseAnimation {duration: 3000}
            ParallelAnimation{
                SequentialAnimation {
                    NumberAnimation { targets: fogBlur2; properties: "opacity"; from: 0; to: 0.8; duration: 1000 }
                    PauseAnimation {duration: 8000}
                    NumberAnimation { targets: fogBlur2; properties: "opacity"; from: 0.8; to: 0; duration: 1000 }
                }
                NumberAnimation { target: fogBlur2; property: "anchors.leftMargin"; from: weatherCondition.width/3.6; to: weatherCondition.height/-7.5; duration: 10000}
            }
        }
    }

    // CONDITION TRANSITION ANIMATIONS
    ParallelAnimation {
        id: anim_sunIn
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: sun; properties: "opacity"; to: 1; duration: 1000 }
        ScriptAction {script:{sun.anchors.horizontalCenterOffset=0;sun.anchors.topMargin=0;__sun = true;anim_01.start();}}
    }
    ParallelAnimation {
        id: anim_moonIn
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: moon; properties: "opacity"; to: 1; duration: 1000 }
        ScriptAction {script:{moon.anchors.horizontalCenterOffset=0;moon.anchors.topMargin=0;__moon = true;}}
    }
    ParallelAnimation {
        id: anim_sunOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: sun; properties: "opacity"; to: 0; duration: 1000 }
        ScriptAction {script:{__sun = false;anim_01.stop();}}
    }
    ParallelAnimation {
        id: anim_moonOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: moon; properties: "opacity"; to: 0; duration: 1000 }
        ScriptAction {script:__moon = false;}
    }
    SequentialAnimation {
        id: anim_moon2sun
        paused: (running && !weatherCondition.visible)
        ParallelAnimation {
            NumberAnimation { targets: moon; properties: "anchors.horizontalCenterOffset"; from: units.gu(0); to: weatherCondition.width/1.5; duration: 1000 }
            NumberAnimation { easing.type: Easing.InQuad; targets: moon; properties: "anchors.topMargin"; from: units.gu(0); to: weatherCondition.height/2.5; duration: 1000 }
            NumberAnimation { targets: moon; properties: "opacity"; from: 1; to: 0; duration: 1000 }
        }
        ParallelAnimation {
            NumberAnimation { targets: sun; properties: "anchors.horizontalCenterOffset"; from: weatherCondition.width/-1.5; to: units.gu(0); duration: 1000}
            NumberAnimation { easing.type: Easing.OutQuad; targets: sun; properties: "anchors.topMargin"; from: weatherCondition.height/2.5; to: units.gu(0); duration: 1000 }
            NumberAnimation { targets: sun; properties: "opacity"; from: 0; to: 1; duration: 1000 }
        }
        ScriptAction {script:{__sun=true; __moon=false;anim_01.start();}}
    }
    SequentialAnimation {
        id: anim_sun2moon
        paused: (running && !weatherCondition.visible)
        ParallelAnimation {
            NumberAnimation { targets: sun; properties: "anchors.horizontalCenterOffset"; from: units.gu(0); to: weatherCondition.width/1.5; duration: 1000 }
            NumberAnimation { easing.type: Easing.InQuad; targets: sun; properties: "anchors.topMargin"; from: units.gu(0); to: weatherCondition.height/2.5; duration: 1000 }
            NumberAnimation { targets: sun; properties: "opacity"; from: 1; to: 0; duration: 1000 }
        }
        ParallelAnimation {
            NumberAnimation { targets: moon; properties: "anchors.horizontalCenterOffset"; from: weatherCondition.width/-1.5; to: units.gu(0); duration: 1000}
            NumberAnimation { easing.type: Easing.OutQuad; targets: moon; properties: "anchors.topMargin"; from: weatherCondition.height/2.5; to: units.gu(0); duration: 1000 }
            NumberAnimation { targets: moon; properties: "opacity"; from: 0; to: 1; duration: 1000 }
        }
        ScriptAction {script:{__sun=false; __moon=true;anim_01.stop();}}
    }
    ParallelAnimation {
        id: anim_fewCloudsIn
        paused: (running && !weatherCondition.visible)
        SequentialAnimation{
            PauseAnimation {duration: 1000}
            ScriptAction {script:{
                    anim_02.restart();
                }}
        }
        ScriptAction {script:__fewClouds = true;}
    }
    ParallelAnimation {
        id: anim_fewCloudsOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: cloud1; properties: "opacity"; to: 0; duration: 1000}
        NumberAnimation { targets: cloud2; properties: "opacity"; to: 0; duration: 1000}
        SequentialAnimation{
            PauseAnimation {duration: 1000}
            ScriptAction {script:{
                    anim_02.stop();
                }}
        }
        ScriptAction {script:__fewClouds = false;}
    }
    ParallelAnimation {
        id: anim_scatCloudsIn
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: cloud1; properties: "anchors.leftMargin"; to: weatherCondition.width/6; duration: 1000 }
        NumberAnimation { target: cloud1; property: "anchors.topMargin"; to: weatherCondition.height/-15; duration: 1000 }
        NumberAnimation { targets: cloud1; properties: "opacity"; to: 1; duration: 1000 }
        NumberAnimation { targets: cloud2; properties: "anchors.leftMargin"; to: weatherCondition.width/-15; duration: 1000 }
        NumberAnimation { target: cloud2; property: "anchors.topMargin"; to: weatherCondition.height/7.5; duration: 1000 }
        NumberAnimation { targets: cloud2; properties: "opacity"; to: 1; duration: 1000 }
        ScriptAction {script:__scattered = true;}
    }
    ParallelAnimation {
        id: anim_scatCloudsOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: cloud1; properties: "anchors.leftMargin"; from: weatherCondition.width/6; to: weatherCondition.width/1.5; duration: 1000 }
        NumberAnimation { targets: cloud1; properties: "opacity"; to: 0; duration: 1000 }
        NumberAnimation { targets: cloud2; properties: "anchors.leftMargin"; from: weatherCondition.width/-15; to: weatherCondition.width/-1.5; duration: 1000 }
        NumberAnimation { targets: cloud2; properties: "opacity"; to: 0; duration: 1000 }
        ScriptAction {script:__scattered = false;}
    }
    ParallelAnimation {
        id: anim_brokenCloudsIn
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: cloud1; properties: "anchors.leftMargin"; to: weatherCondition.width/6; duration: 1000 }
        NumberAnimation { target: cloud1; property: "anchors.topMargin"; to: weatherCondition.height/-15; duration: 1000 }
        NumberAnimation { targets: cloud1; properties: "opacity"; to: 1; duration: 1000 }
        NumberAnimation { targets: cloud_dark1; properties: "anchors.leftMargin"; to: weatherCondition.height/-15; duration: 1000 }
        NumberAnimation { target: cloud_dark1; property: "anchors.topMargin"; to: weatherCondition.height/7.5; duration: 1000 }
        NumberAnimation { targets: cloud_dark1; properties: "opacity"; to: 1; duration: 1000 }
        ScriptAction {script:__broken = true;}
    }
    ParallelAnimation {
        id: anim_brokenCloudsOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: cloud1; properties: "anchors.leftMargin"; from: weatherCondition.width/6; to: weatherCondition.width/1.5; duration: 1000 }
        NumberAnimation { targets: cloud1; properties: "opacity"; to: 0; duration: 1000 }
        NumberAnimation { targets: cloud_dark1; properties: "anchors.leftMargin"; from: weatherCondition.height/-15; to: weatherCondition.width/-1.5; duration: 1000 }
        NumberAnimation { targets: cloud_dark1; properties: "opacity"; to: 0; duration: 1000 }
        ScriptAction {script:__broken = false;}
    }
    ParallelAnimation {
        id: anim_rainIn
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: rain1; properties: "opacity"; to: 1; duration: 1000 }
        NumberAnimation { targets: rain2; properties: "opacity"; to: 1; duration: 1000 }
        ScriptAction {script:__rain = true;}
    }
    ParallelAnimation {
        id: anim_rainOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: rain1; properties: "opacity"; to: 0; duration: 1000 }
        NumberAnimation { targets: rain2; properties: "opacity"; to: 0; duration: 1000 }
        ScriptAction {script:__rain = false;}
    }
    ParallelAnimation {
        id: anim_stormIn
        paused: (running && !weatherCondition.visible)
        ScriptAction {script:{__storm = true; anim_11.restart();}}
    }
    ParallelAnimation {
        id: anim_stormOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: lightning; properties: "opacity"; to: 0; duration: 1 }
        NumberAnimation { targets: lightningfx; properties: "opacity"; to: 0; duration: 1 }
        NumberAnimation { targets: lightningGlow; properties: "opacity"; to: 0; duration: 1 }
        NumberAnimation { targets: cloud1Glow; properties: "opacity"; to: 0; duration: 1 }
        NumberAnimation { targets: cloud_dark1Glow; properties: "opacity"; to: 0; duration: 1 }
        ScriptAction {script:{__storm = false; anim_11.stop();}}
    }
    ParallelAnimation {
        id: anim_snowIn
        paused: (running && !weatherCondition.visible)
        ScriptAction {script:{__snow = true; /*snowflake1_anim.start(); snowflake2_anim.start(); snowflake3_anim.start();*/ anim_13.start();}}
    }
    ParallelAnimation {
        id: anim_snowOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation {targets: snowflake1; properties: "opacity"; to:0; duration: 1000}
        NumberAnimation {targets: snowflake2; properties: "opacity"; to:0; duration: 1000}
        NumberAnimation {targets: snowflake3; properties: "opacity"; to:0; duration: 1000}
        ScriptAction {script:{__snow = false; /*snowflake1_anim.stop(); snowflake2_anim.stop(); snowflake3_anim.stop();*/ /*anim_13.stop();*/}}
    }
    SequentialAnimation {
        id: anim_fogIn
        paused: (running && !weatherCondition.visible)
        PauseAnimation {duration: 1000}
        ScriptAction {script:{anim_50.restart(); script:__fog = true;}}
    }
    ParallelAnimation {
        id: anim_fogOut
        paused: (running && !weatherCondition.visible)
        NumberAnimation { targets: fogBlur1; properties: "opacity"; to: 0; duration: 1000}
        NumberAnimation { targets: fogBlur2; properties: "opacity"; to: 0; duration: 1000}
        SequentialAnimation{
            PauseAnimation {duration: 1000}
            ScriptAction {script:{
                    anim_50.stop();
                }}
        }
        ScriptAction {script:__fog = false;}
    }

    states: [
        State {
            name: "01d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moon2sun.start(); else if(!__sun) anim_sunIn.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__fog) anim_fogOut.start();
                }
            }
        },
        State {
            name: "01n"
            StateChangeScript {
                script: {
                    if(__sun) anim_sun2moon.start(); else if(!__moon) anim_moonIn.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__fog) anim_fogOut.start();
                }
            }
        },
        State {
            name: "02d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moon2sun.start(); else if(!__sun) anim_sunIn.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__fewClouds) anim_fewCloudsIn.start();
                }
            }
        },
        State {
            name: "02n"
            StateChangeScript {
                script: {
                    if(__sun) anim_sun2moon.start(); else if(!__moon) anim_moonIn.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__fewClouds) anim_fewCloudsIn.start();
                }
            }

            PropertyChanges {
                target: lightning
                opacity: 0
            }
        },
        State {
            name: "03d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moon2sun.start(); else if(!__sun) anim_sunIn.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__scattered) anim_scatCloudsIn.start();
                }
            }
        },
        State {
            name: "03n"
            StateChangeScript {
                script: {
                    if(__sun) anim_sun2moon.start(); else if(!__moon) anim_moonIn.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__scattered) anim_scatCloudsIn.start();
                }
            }
        },
        State {
            name: "04d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__broken) anim_brokenCloudsIn.start();
                }
            }
        },
        State {
            name: "04n"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__broken) anim_brokenCloudsIn.start();
                }
            }
        },
        State {
            name: "09d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__broken) anim_brokenCloudsIn.start();
                    if(!__rain) anim_rainIn.start();
                }
            }
        },
        State {
            name: "09n"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__broken) anim_brokenCloudsIn.start();
                    if(!__rain) anim_rainIn.start();
                }
            }
        },
        State {
            name: "10d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moon2sun.start(); else if(!__sun) anim_sunIn.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__scattered) anim_scatCloudsIn.start();
                    if(!__rain) anim_rainIn.start();
                }
            }
        },
        State {
            name: "10n"
            StateChangeScript {
                script: {
                    if(__sun) anim_sun2moon.start(); else if(!__moon) anim_moonIn.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__scattered) anim_scatCloudsIn.start();
                    if(!__rain) anim_rainIn.start();
                }
            }
        },
        State {
            name: "11d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__broken) anim_brokenCloudsIn.start();
                    if(!__storm) anim_stormIn.start();
                }
            }
        },
        State {
            name: "11n"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__snow) anim_snowOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__broken) anim_brokenCloudsIn.start();
                    if(!__storm) anim_stormIn.start();
                }
            }
        },
        State {
            name: "13d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__broken) anim_brokenCloudsIn.start();
                    if(!__snow) anim_snowIn.start();
                }
            }
        },
        State {
            name: "13n"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__fog) anim_fogOut.start();
                    if(!__broken) anim_brokenCloudsIn.start();
                    if(!__snow) anim_snowIn.start();
                }
            }
        },
        State {
            name: "50d"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__snow) anim_snowOut.start();
                    if(!__fog) anim_fogIn.start();
                }
            }
        },
        State {
            name: "50n"
            StateChangeScript {
                script: {
                    if(__moon) anim_moonOut.start();
                    if(__sun) anim_sunOut.start();
                    if(__fewClouds) anim_fewCloudsOut.start();
                    if(__scattered) anim_scatCloudsOut.start();
                    if(__rain) anim_rainOut.start();
                    if(__storm) anim_stormOut.start();
                    if(__broken) anim_brokenCloudsOut.start();
                    if(__snow) anim_snowOut.start();
                    if(!__fog) anim_fogIn.start();
                }
            }
        }
    ]
}
