# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2013 Canonical
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

"""Tests for Weather app"""

from __future__ import absolute_import

from testtools.matchers import Equals
from autopilot.matchers import Eventually

from ubuntu_weather_app.tests import WeatherTestCase, DatabaseMixin
from ubuntu_weather_app.tests.weatherdata import locations_data

class TestMainView(WeatherTestCase, DatabaseMixin):
    """Tests creating weather"""

    """ This is needed to wait for the application to start.
        In the testfarm, the application may take some time to show up."""
    def setUp(self):
        self.clean_db()
        self.launch_and_quit_app()
        self.save_locations_to_storage(locations_data)
        super(TestMainView, self).setUp()
        self.assertThat(
            self.main_window.get_qml_view().visible, Eventually(Equals(True)))

    def tearDown(self):
        super(TestMainView, self).tearDown()

    def test_switch_tabs(self):
        """Test start of app with two locations and switch from first to
        second tab"""
        # first tab should be visible after start
        tabs =  self.main_window.get_tabs()
        tabObjects = self.main_window.get_objects('LocationTab','LocationTab')
        self.assertThat(tabs.selectedTabIndex, Eventually(Equals(0)))
        self.assertThat(tabObjects[0].visible, Eventually(Equals(True)))
        self.assertThat(tabObjects[1].visible, Eventually(Equals(False)))
        self.assertThat(tabObjects[0].title, Eventually(Equals("London")))
        # switch to next tab
        self.main_window.switch_to_tab(1)
        self.assertThat(tabs.selectedTabIndex, Eventually(Equals(1)))
        self.assertThat(tabObjects[0].visible, Eventually(Equals(False)))
        self.assertThat(tabObjects[1].visible, Eventually(Equals(True)))
        self.assertThat(tabObjects[1].title, Eventually(Equals("Hamburg")))

    def test_refresh_tabs(self):
        # get the dates from the test data
        curr_dates = self.main_window.get_objects('Label','DayDateLabel')
        tab1_curr_date = curr_dates[0].text
        tab2_curr_date = curr_dates[1].text

        # refresh and wait till loading has finished
        self.main_window.click_toolbar_button("RefreshButton")
        load_indicator = self.main_window.get_object('ActivityIndicator', 'LoadingSpinner')
        self.assertThat(load_indicator.running, Eventually(Equals(False)))

        # get the data from the refreshed tabs, have to be new
        refreshed_dates = self.main_window.get_objects('Label','DayDateLabel')
        self.assertNotEqual(tab1_curr_date, refreshed_dates[0].text)
        self.assertNotEqual(tab2_curr_date, refreshed_dates[1].text)
