/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Raúl Yeguas <neokore@gmail.com>
 *              Martin Borho <martin@borho.net>
 */
import QtQuick 2.0
import Ubuntu.Components 0.1
import "components" as Components
import Ubuntu.Components.Popups 0.1

MainView {
    // objectName for functional testing purposes (autopilot-qt5)
    objectName: "weather"
    applicationName: "ubuntu-weather-app"

    id: mainView
    
    width: units.gu(50)
    height: units.gu(75)

    property var locationsList: []
    property var tabsObject: null
    // set default values for settings here
    property var settings: {"units":"metric"}

    WorkerScript {
        id: locationDataWorker
        source: "components/WeatherApi.js"
        onMessage: {
            if(!messageObject.error) {
                if(messageObject.action === "updateData") {
                    messageObject.result.forEach(function(loc) {
                        if(loc["save"] === true) {
                            storage.updateLocation(loc.db.id, loc);
                        }
                    });
                    buildTabs(messageObject.result);
                }
            } else {
                console.log(messageObject.error.msg+" / "+messageObject.error.request.url)
            }
        }
    }

    // see https://bugs.launchpad.net/ubuntu-ui-toolkit/+bug/1124071, temporary workaround
    function buildTabs(locations) {
        // check if there was a location added
        var locLength = locations.length,
            locBeforeLen = locationsList.length,
            focusToLast = (locBeforeLen > 0 && locLength > locBeforeLen) ? true : false;
        // show locationmanager when no location is added
        if(locLength === 0) {
            showLocationManager()
            return;
        }

        locationsList = locations;
        if(tabsObject !== null) {
            tabsObject.destroy()
        }
        var tabsString = "import QtQuick 2.0; import Ubuntu.Components 0.1; import Ubuntu.Components.Popups 0.1; import \"components\" as Components; "
                + "Tabs {id: tabs; objectName: 'rootTabs'; anchors.fill: parent;"
        if(locLength > 0) {
            for(var x=0;x<locLength;x++) {
                tabsString += "Components.LocationTab {title: '"+locations[x].location.name+"'; locationIndex: "+x+"} "
            };
        }
        tabsString += "}"; // END Tabs componen
        if(bigLoading !== null) {
            bigLoading.destroy();
        }
        loading.running = false;
        tabsObject = Qt.createQmlObject(tabsString, tabPage, "tabs")
        if(focusToLast)
            tabsObject.selectedTabIndex = locLength -1;
    }

    function refreshData(from_storage, force_refresh) {
        if(bigLoading === null) {
             loading.running = true;
        }
        //
        if(from_storage === true && force_refresh !== true) {
            storage.getLocations(buildTabs);
        } else {
            storage.getLocations(function(locations) {
                locationDataWorker.sendMessage({
                    action: "updateData",
                    params: {locations:locations, force: force_refresh}
                })
            });
        }
    }

    function showLocationManager() {
        pageStack.push(locationManager)
        locationManager.loadData()
    }

    function showSettings() {
        PopupUtils.open(settingsSheet)
    }

    Component.onCompleted: {
        //storage.clearDB();
        //storage.clearSetting('units');
        storage.getSettings(function(storedSettings) {
            for(var settingName in storedSettings) {
                settings[settingName] = storedSettings[settingName];
            }
            refreshData();
        })
    }

    Components.SettingsSheet {
        id: settingsSheet
    }
    
    Components.Storage{
        id: storage
    }

    Components.LocationManagerPage {
        id:locationManager
    }

    Components.AddLocationPage {
        id:addLocationPage
    }

    PageStack {
        id: pageStack
        Component.onCompleted: push(tabPage)

        Page {
            id: tabPage
            objectName: "MainPage"
            visible: false
            ActivityIndicator{
                id:loading
                objectName: "LoadingSpinner"
                running: false
                z: 1
                anchors{
                    top: parent.top
                    topMargin: units.gu(0.5)
                    right: parent.right
                    rightMargin: units.gu(1)
                }
            }
            ActivityIndicator{
                id:bigLoading
                objectName: "LoadingSpinner"
                running: true
                z: 1
                anchors.centerIn: parent
            }
        }
    }
}
